
-- This function gets the player's current wallet items and updates the saved table values
function LoadWallet()

	-- Check table exists
	if _ITEMS == nil then _ITEMS = {} end;
	if _ITEMS["MONEY"] == nil then
		_ITEMS["MONEY"] = {};
		_ITEMS["MONEY"]["CHARACTERS"] = {};
	end

	-- Reset qtys for current character to zero (incase the item info is saved but no longer in wallet)
	for k,v in pairs (_ITEMS) do
		if v["CHARACTERS"] ~= nil and v["CHARACTERS"][CHARNAME] ~= nil and v["CHARACTERS"][CHARNAME].QTY ~= nil then v["CHARACTERS"][CHARNAME].QTY = 0 end;
	end

	-- Loop through wallet to get items
	for i=1, WALLET:GetSize() do

		local curITEM = WALLET:GetItem(i);
		local ITEMNAME = curITEM:GetName();

		-- Check if the item exists etc..
		UpdateItem(curITEM);

		-- Register the item for events
		RegisterQtyEvent(curITEM);

		-- Set quantity in session start table
		_SESSIONSTART[ITEMNAME] = curITEM:GetQuantity();
	end

	-- Update gold
	if _ITEMS["MONEY"]["CHARACTERS"][CHARNAME] == nil then
		_ITEMS["MONEY"]["CHARACTERS"][CHARNAME] = {};
	end

	_ITEMS["MONEY"]["CHARACTERS"][CHARNAME]["QTY"] = CHARATTS:GetMoney();
	_ITEMS["MONEY"]["CHARACTERS"][CHARNAME]["DISPLAY"] = true;
	_SESSIONSTART["MONEY"] =  CHARATTS:GetMoney();

end


-- This function is called when an item is removed from the barter wallet.
function RemoveItem(ITEM)

	if ITEM == nil then return end;

	local ITEMNAME = tostring(ITEM:GetName());

	-- Make sure item & character entries exist
	if _ITEMS[ITEMNAME] ~= nil and _ITEMS[ITEMNAME]["CHARACTERS"] ~= nil and _ITEMS[ITEMNAME]["CHARACTERS"][CHARNAME] ~= nil then
		_ITEMS[ITEMNAME]["CHARACTERS"][CHARNAME]["QTY"] = 0;
	end

	-- Check if shared item
	if _ITEMS[ITEMNAME]["CHARACTERS"]["SHARED"] ~= nil then _ITEMS[ITEMNAME]["CHARACTERS"]["SHARED"] = 0 end;

	-- Update Display
	UpdateDisplay(ITEMNAME);
end


-- This function will check if an item exists in the main table, if not it will create the entry.
-- It will also update the quantity
function UpdateItem(ITEM,UPDATEDISPLAY)

	if ITEM == nil then return end;

	local ITEMNAME = tostring(ITEM:GetName());

	-- Check to see if item exists already, if not then create the entry.
	if _ITEMS[ITEMNAME] == nil then
		_ITEMS[ITEMNAME] = {};
		_ITEMS[ITEMNAME]["IMAGES"] = {};
		_ITEMS[ITEMNAME]["IMAGES"]["NORMAL"] = "0x" .. TO_HEX(ITEM:GetImage());
		_ITEMS[ITEMNAME]["IMAGES"]["SMALL"] = "0x" .. TO_HEX(ITEM:GetSmallImage());
		_ITEMS[ITEMNAME]["CHARACTERS"] = {};
	end

	-- Check to see if character entry exists for item, if not create it
	if _ITEMS[ITEMNAME]["CHARACTERS"][CHARNAME] == nil then
		_ITEMS[ITEMNAME]["CHARACTERS"][CHARNAME] = {};
		_ITEMS[ITEMNAME]["CHARACTERS"][CHARNAME]["DISPLAY"] = SETTINGS.AUTOADD;

		-- Register the new item for events
		RegisterQtyEvent(ITEM);
	end

	_ITEMS[ITEMNAME]["CHARACTERS"][CHARNAME]["QTY"] = ITEM:GetQuantity();

	-- Check if item is account shared
	if ITEM:IsAccountItem() == true then
		_ITEMS[ITEMNAME]["CHARACTERS"]["SHARED"] = ITEM:GetQuantity();
		_ITEMS[ITEMNAME]["CHARACTERS"][CHARNAME]["QTY"] = nil;
	end

	-- Check to see if display should be updated
	if UPDATEDISPLAY == true then
		UpdateDisplay(ITEMNAME);
	end

end


-- This function registers the quantity changed event for each item in the wallet
function RegisterQtyEvent(ITEM)

	if ITEM == nil then return end;

	ITEM.QuantityChanged = function ()
		-- Quantity value changed
		UpdateItem(ITEM,true);
	end
end


-- This function resets the session start table and regrabs the current wallet quantities.
function ResetStartVals()

	btnRefresh:SetVisible(false);

	_SESSIONSTART = nil;
	_SESSIONSTART = {};

	for i=1, WALLET:GetSize() do

		local curITEM = WALLET:GetItem(i);
		local ITEMNAME = curITEM:GetName();

		-- Set quantity in session start table
		_SESSIONSTART[ITEMNAME] = curITEM:GetQuantity();

		--print(ITEMNAME .. " = " .. curITEM:GetQuantity());
	end

	_SESSIONSTART["MONEY"] =  CHARATTS:GetMoney();

	-- Clear Display
	lstCurrencyDisplay:ClearItems();
	cItemContainer = nil;
	cItemContainer = {};
	BuildFullList();

end


-- This function takes the MONEY value and converts it to gold, silver, copper (Money is usually the copper value)
function GetMoneyComponents(MONEY)

	local _COMPONENTS = {["G"] = 0;["S"] = 0;["C"] = 0;};

	if MONEY == nil then return _COMPONENTS end;

	MONEY = math.abs(MONEY);

	-- 26002544 = 260g 025s 44c

	_COMPONENTS.G = math.floor(MONEY/100000); -- Doing calculations this way because math.modf returns odd numbers with long decimals.
	MONEY = MONEY - (_COMPONENTS.G*100000);
	_COMPONENTS.S = math.floor(MONEY/100);
	MONEY = MONEY - (_COMPONENTS.S*100);
	_COMPONENTS.C = MONEY;

	return _COMPONENTS;
end


-- This function gets the total value of gold across all saved characters
function GetAllGold()

	local totalGold = 0;

	if _ITEMS["MONEY"] == nil or _ITEMS["MONEY"]["CHARACTERS"] == nil then return 0 end;

	for k,v in pairs(_ITEMS["MONEY"]["CHARACTERS"]) do
		if v["QTY"] ~= nil then totalGold = totalGold + v["QTY"] end;
	end

	return totalGold;
end


-- This function returns the money components as a string
function GetMoneyString(VALUE)

	if VALUE==nil or type(VALUE)~="number" then return "0" end;

	local _moneyComp = GetMoneyComponents(VALUE);
	local sOutput = "";

	if tonumber(_moneyComp.G) ~= 0 then sOutput = sOutput .. comma_value(_moneyComp.G) .. "g " end;
	if tonumber(_moneyComp.S) ~= 0 then sOutput = sOutput .. _moneyComp.S .. "s " end;
	if tonumber(_moneyComp.C) ~= 0 then sOutput = sOutput .. _moneyComp.C .. "c " end;

	if sOutput == "" then sOutput = "0g" end;

	return sOutput;
end


-- This function handles the showing/hiding of the background
function HandleBackground()
	cCurrencyBarBackLeft:SetVisible(SETTINGS.SHOWBACKGROUND);
	cCurrencyBarBackCenter:SetVisible(SETTINGS.SHOWBACKGROUND);
	cCurrencyBarBackRight:SetVisible(SETTINGS.SHOWBACKGROUND);
end
