-- Turbine Imports..
import "Turbine";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";

-- Plugin Imports..
import "GaluhadPlugins.CurrencyTracker.ToolTip";
import "GaluhadPlugins.CurrencyTracker.GeneralFunctions";
import "GaluhadPlugins.CurrencyTracker.CTFunctions";
import "GaluhadPlugins.CurrencyTracker.Globals";
import "GaluhadPlugins.CurrencyTracker.Images";
import "GaluhadPlugins.CurrencyTracker.Strings";
import "GaluhadPlugins.CurrencyTracker.Onscreen";
import "GaluhadPlugins.CurrencyTracker.MessageBox";

-- Windows --
import "GaluhadPlugins.CurrencyTracker.CurrencyBar";
import "GaluhadPlugins.CurrencyTracker.SettingsWin";
import "GaluhadPlugins.CurrencyTracker.LoadProgress";

-- Other imports --
import "GaluhadPlugins.CurrencyTracker.Commands";


-----------------------------------------------------------------------------------------------------------

function saveData()

	-- Store the settings table.
	Turbine.PluginData.Save(Turbine.DataScope.Character, "CurrencyTracker_Settings", SETTINGS);
	Turbine.PluginData.Save(Turbine.DataScope.Server, "CurrencyTracker_Items", _ITEMS);

end


function loadData()
	---------------------------------------------------------------------------------------------------------------------------------

	-- SAVED SETTINGS --
	local SavedSettings = {};

	function GetSavedSettings()
		SavedSettings = Turbine.PluginData.Load(Turbine.DataScope.Character, "CurrencyTracker_Settings");
	end

	if pcall(GetSavedSettings) then
		-- Loaded without error
		SavedSettings = Turbine.PluginData.Load(Turbine.DataScope.Character, "CurrencyTracker_Settings");
	else
		-- Loaded with errors
		SavedSettings = nil;
		Turbine.Shell.WriteLine(_LANG.SETTINGSLOADERROR[SETTINGS.LANGUAGE]);
	end

	-- Check the saved settings to make sure it is still compatible with newer updates, add in any missing default settings
	if type(SavedSettings) == 'table' then
		local tempSETTINGS = {};
		tempSETTINGS = deepcopy(DEFAULT_SETTINGS);
		SETTINGS = mergeTables(tempSETTINGS,SavedSettings);
	else
		SETTINGS = deepcopy(DEFAULT_SETTINGS);
	end


	-- SAVED ITEMS ----------------------------------------------------------------------------------------------------------------0
	function GetSavedItems()
		_ITEMS = Turbine.PluginData.Load(Turbine.DataScope.Server, "CurrencyTracker_Items");
	end

	if pcall(GetSavedItems) then
		-- Loaded without error
		GetSavedItems();
	else
		-- Loaded with errors
		_ITEMS = {};
		Turbine.Shell.WriteLine(_LANG.ITEMSLOADERROR[SETTINGS.LANGUAGE]);
	end

	----------------------------------------------------------------------------------------------------------------------------------
end


function DrawWindows()

	DrawCurrencyBar();
	DrawLoadBar();
	DrawSettingsWindow();

end


function RegisterEvents()

	CHARATTS.MoneyChanged = function ()
		_ITEMS["MONEY"]["CHARACTERS"][CHARNAME]["QTY"] = CHARATTS:GetMoney();
		UpdateDisplay("MONEY");
	end

	WALLET.ItemAdded = function (sender, args) -- args.Index  or  args.Item
		local ITEMNAME = args.Item:GetName();
		Debug(_LANG.NEWITEM[SETTINGS.LANGUAGE] .. ": " .. ITEMNAME);
		UpdateItem(args.Item,true);
		BuildFullList();
	end

	WALLET.ItemRemoved = function (sender, args) -- args.Index or args.Item
		local ITEMNAME = args.Item:GetName();
		Debug(_LANG.NOCURRENCY[SETTINGS.LANGUAGE] .. ": " .. ITEMNAME);
		RemoveItem(args.Item);
		BuildFullList();
	end

end


Turbine.Plugin.Unload = function (sender, args)
	-- Save the data when the plugin unloads.
	saveData();
end



-- Initiate load sequence
loadData();
--InitiateChatLogger();
DrawWindows();
RegisterCommands();
SETTINGS.SHOWSCREEN = true;


-- Load text
Debug("Loaded '" .. Plugins["Currency Tracker"]:GetName() .. "' v" .. Plugins["Currency Tracker"]:GetVersion() .. " by Galuhad [Eldar]");
Debug(_LANG.COMMAND[SETTINGS.LANGUAGE]);
Debug(_LANG.COMMAND2[SETTINGS.LANGUAGE]);

